import os

from django.conf import settings
from django.dispatch import receiver
from django.db.models.signals import post_save

from . import models, utils, s3_uploader


@receiver(post_save, sender=models.Video)
def generate_default_thumbnail_for_video(sender, instance, **kwargs):
    if not instance.thumbnail and instance.local_file:
        if os.path.isfile(instance.local_file.path):
            thumbnail_name = utils.generate_thumbnail(instance.local_file)
            thumbnail_path = f'{settings.BASE_DIR}/videos/{thumbnail_name}'

            content = utils.get_thumbnail_content(thumbnail_path)
            key = f'videos/{instance.id}/{thumbnail_name}'
            content_type = 'image/jpeg'
            instance.thumbnail = s3_uploader.upload_file(content, key, content_type)

            instance.save(update_fields=['thumbnail'])

            os.remove(thumbnail_path)
