import os

from celery import Celery
from celery.schedules import crontab
from celery.signals import after_setup_logger

# set the default Django settings module for the 'celery' program.
os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'cp_video.settings.local')

app = Celery('cp_video')

# Using a string here means the worker don't have to serialize
# the configuration object to child processes.
# - namespace='CELERY' means all celery-related configuration keys
#   should have a `CELERY_` prefix.
app.config_from_object('django.conf:settings', namespace='CELERY')

# Erase all messages from all known task queues.
app.control.purge()

# Load task modules from all registered Django app configs.
app.autodiscover_tasks()


app.conf.beat_schedule = {
    'send_video_to_s3': {
        'task': 'apps.core.tasks.send_video_to_s3',
        'schedule': 60.0,
    },
}
